==> haskell-witherable-0.4.2-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-3IvOM55Cfvt7BZpiA7Wzt6
key:                  witherable-0.4.2-3IvOM55Cfvt7BZpiA7Wzt6
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  5b8188f88f2fd8b1fcce57251f83322f
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-3IvOM55Cfvt7BZpiA7Wzt6
depends:
    base-4.17.2.1 base-orphans-0.9.3-4qtOLbD3TWGEaOHg3PqNw7
    containers-0.6.7 hashable-1.4.5.0-DrXzgEMDRcV8gNOMGO5wPZ
    indexed-traversable-0.1.4-CjelN0MuLjgFb4a6UstzaC
    indexed-traversable-instances-0.1.2-9mJUp86wqzsFQdunQAAuWZ
    transformers-0.5.6.2
    unordered-containers-0.2.20-FLM1pZb3BI5FpyNo5sVXNv
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witherable-0.4.2-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-7GS3ZhHrPIkAPMDlpnzagZ
key:                  witherable-0.4.2-7GS3ZhHrPIkAPMDlpnzagZ
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  0796492c98f1988dd81320978a29973e
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-7GS3ZhHrPIkAPMDlpnzagZ
depends:
    base-4.17.2.1 base-orphans-0.9.3-2as08b5FY9j3vbk2eQgJQ5
    containers-0.6.7 hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    indexed-traversable-0.1.4-8RoXG5saZErHeqMhoihF0x
    indexed-traversable-instances-0.1.2-7HC0GdRjKNmJRRNOk5sorh
    transformers-0.5.6.2
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
